<?php
declare(strict_types=1);

namespace App\Utils\Transfer\HisHttpClient;

use App\Exceptions\GeneralException;
use App\Utils\Transfer\HttpTransferAbstract;
use App\Utils\Transfer\SoapTransferAbstract;
use Exception;
use Random\RandomException;

class ClientMockHttpTransfer extends HttpTransferAbstract
{
    /**
     * ClientMockTransfer Construct
     * @param string $his_name
     */
    public function __construct(string $his_name = "")
    {
        parent::__construct($his_name);
    }

    /**
     * 设置客户端选项
     * @return array
     */
    public function clientHeaders(): array
    {
        return [];
    }

    /**
     * @param string $class_name
     * @return $this
     */
    public function transferClass(string $class_name): static
    {
        return $this;
    }

    /**
     * @throws GeneralException
     */
    public function transferMethod(string $method, string $request_name, array $request_data = []): self
    {
        // 使用 match 替代 switch
        return match ($request_name) {
            'CreateCardPatInfo' => $this->mockRegisterCard($request_data),
            'GetCardInfo' => $this->mockGetPatientInfo($request_data),
            'GetDepType' => $this->mockGetDepLists($request_data),
            'GetDoctList' => $this->mockGetDoctorLists($request_data),
            'PayRegTrade' => $this->mockConfirmRegister($request_data),
            'GetGHMXList' => $this->mockGetRegisterRecordLists($request_data),
            'GHCancelCheck' => $this->mockCheckRefundRegisterStatus($request_data),
            'GHCancelConfirm' => $this->mockRefundRegister($request_data),
            'ListVisitRec' => $this->mockGetPendingLists($request_data),
            'ListRecipe' => $this->mockGetPendingDetails($request_data),
            'PayBillTrade' => $this->mockConfirmPayment($request_data),
            'OutpatientExpenseRecord' => $this->mockGetPaidLists($request_data),
            'OutpatientDetailRecord' => $this->mockGetPaidDetails($request_data),
            'CreateOutpatientinvoiceEBill' => $this->mockCreateElectronInvoice($request_data),
            'SendOutpatientinvoiceEBill' => $this->mockSendElectronInvoiceToHis($request_data),
            'GetDictionary' => $this->mockGetDictionaryLists($request_data),
            'GetChargeList' => $this->mockGetChargeList($request_data),
            default => throw new GeneralException("Method '{$request_name}' not found"),
        };
    }

    /**
     * 响应格式化
     * @param mixed $data
     * @return mixed
     * @throws Exception
     */
    public function responseFormat(mixed $data): mixed
    {
        try {
            // 此处为json格式
            return json_decode((string)$data, true);
        } catch (Exception $e) {
            throw new Exception($e->getMessage());
        }
    }

    /**
     * 获取返回值
     * @param bool $is_format
     * @return mixed
     * @throws Exception
     */
    public function getResult(bool $is_format = true): mixed
    {
        return $this->responseFormat($this->transfer_response);
    }

    /**
     * mockRegisterCard
     * @param array $params
     * @return self
     * @throws RandomException
     */
    private function mockRegisterCard(array $params): self
    {
        $patient_id = random_int(1000000, 9999999);
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":{"patientId":"'. $patient_id.'"}}';

        return $this;
    }

    /**
     * mockGetPatientInfo
     * @param array $params
     * @return self
     * @throws RandomException
     */
    private function mockGetPatientInfo(array $params): self
    {
        $patient_id = random_int(1000000, 9999999);
        $patient_number = random_int(100000, 999999). random_int(100000, 999999);
        $card_no = &$params['json']['cardNo'];
        $name = &$params['json']['name'];
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":{"patientId":"'. $patient_id.' ","cardNo":"'. $card_no. '","name":"'. ($name ?: '谭玉山').'","sex":"1","birthday":"1999-03-24","cardStatus":"0","naturePatients":"123","patientNumber":"'. $patient_number. '"}}';

        return $this;
    }

    /**
     * mockGetDepLists
     * @param array $params
     * @return self
     */
    private function mockGetDepLists(array $params): self
    {
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":[{"typeId":"17","typeName":"泌尿外科"},{"typeId":"20","typeName":"体检办证"},{"typeId":"31","typeName":"内分泌科"},{"typeId":"01","typeName":"内科"},{"typeId":"05","typeName":"口腔科"},{"typeId":"19","typeName":"消化内科"},{"typeId":"29","typeName":"呼吸内科门诊"},{"typeId":"33","typeName":"中医减重门诊"},{"typeId":"03","typeName":"中医康复"},{"typeId":"18","typeName":"产前门诊"},{"typeId":"04","typeName":"五官科"},{"typeId":"10","typeName":"妇产科"},{"typeId":"16","typeName":"全科医生门诊"},{"typeId":"28","typeName":"儿童青少年心理门诊"},{"typeId":"02","typeName":"普外科"},{"typeId":"25","typeName":"儿科"},{"typeId":"27","typeName":"精神心理科"},{"typeId":"07","typeName":"急诊内科"},{"typeId":"09","typeName":"皮肤科"},{"typeId":"14","typeName":"急诊外科"},{"typeId":"15","typeName":"骨科"},{"typeId":"26","typeName":"治未病科"},{"typeId":"06","typeName":"专家门诊"},{"typeId":"11","typeName":"妇保门诊"},{"typeId":"12","typeName":"儿保门诊"},{"typeId":"32","typeName":"血液透析门诊"},{"typeId":"08","typeName":"天灸门诊"},{"typeId":"24","typeName":"神经内科"},{"typeId":"30","typeName":"助产士门诊"}]}';

        return $this;
    }

    /**
     * mockGetDoctorLists
     * @param array $params
     * @return self
     */
    private function mockGetDoctorLists(array $params): self
    {
        $date = &$params['json']['date'];
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":[{"doctId":"10488","doctName":"梁燕华","docTitle":"副主任医师","depLocation":"","isksDoc":"1","doctotVisitInfoList":[{"doctId":"10488","regId":"916601","rankId":"1","rankName":"上午","startTime":"08:00","endTime":"08:30","fee":"0","feeCode":"","regCount":"4","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916602","rankId":"1","rankName":"上午","startTime":"08:30","endTime":"09:00","fee":"0","feeCode":"","regCount":"3","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916603","rankId":"1","rankName":"上午","startTime":"09:00","endTime":"09:30","fee":"0","feeCode":"","regCount":"3","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916604","rankId":"1","rankName":"上午","startTime":"09:30","endTime":"10:00","fee":"0","feeCode":"","regCount":"3","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916605","rankId":"1","rankName":"上午","startTime":"10:00","endTime":"10:30","fee":"0","feeCode":"","regCount":"1","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916606","rankId":"1","rankName":"上午","startTime":"10:30","endTime":"11:00","fee":"0","feeCode":"","regCount":"3","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916607","rankId":"1","rankName":"上午","startTime":"11:00","endTime":"11:30","fee":"0","feeCode":"","regCount":"4","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916608","rankId":"1","rankName":"上午","startTime":"11:30","endTime":"12:00","fee":"0","feeCode":"","regCount":"5","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916609","rankId":"2","rankName":"下午","startTime":"14:00","endTime":"14:30","fee":"0","feeCode":"","regCount":"4","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916610","rankId":"2","rankName":"下午","startTime":"14:30","endTime":"15:00","fee":"0","feeCode":"","regCount":"4","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916611","rankId":"2","rankName":"下午","startTime":"15:00","endTime":"15:30","fee":"0","feeCode":"","regCount":"4","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916612","rankId":"2","rankName":"下午","startTime":"15:30","endTime":"16:00","fee":"0","feeCode":"","regCount":"4","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916613","rankId":"2","rankName":"下午","startTime":"16:00","endTime":"16:30","fee":"0","feeCode":"","regCount":"4","noVisits":"0","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10488","regId":"916017","rankId":"2","rankName":"下午","startTime":"16:30","endTime":"17:00","fee":"0","feeCode":"","regCount":"5","noVisits":"0","visitDate":"'. $date.'","timeSlot":null}]},{"doctId":"10446","doctName":"陈秀纯","docTitle":"主治医师","depLocation":"","isksDoc":"1","doctotVisitInfoList":[{"doctId":"10446","regId":"916156","rankId":"1","rankName":"上午","startTime":"08:00","endTime":"08:30","fee":"0","feeCode":"","regCount":"2","noVisits":"1","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916157","rankId":"1","rankName":"上午","startTime":"08:30","endTime":"09:00","fee":"0","feeCode":"","regCount":"2","noVisits":"1","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916158","rankId":"1","rankName":"上午","startTime":"09:00","endTime":"09:30","fee":"0","feeCode":"","regCount":"3","noVisits":"2","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916160","rankId":"1","rankName":"上午","startTime":"10:00","endTime":"10:30","fee":"0","feeCode":"","regCount":"2","noVisits":"3","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916161","rankId":"1","rankName":"上午","startTime":"10:30","endTime":"11:00","fee":"0","feeCode":"","regCount":"2","noVisits":"3","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916162","rankId":"1","rankName":"上午","startTime":"11:00","endTime":"11:30","fee":"0","feeCode":"","regCount":"4","noVisits":"3","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916163","rankId":"1","rankName":"上午","startTime":"11:30","endTime":"12:00","fee":"0","feeCode":"","regCount":"3","noVisits":"3","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916164","rankId":"2","rankName":"下午","startTime":"14:00","endTime":"14:30","fee":"0","feeCode":"","regCount":"3","noVisits":"1","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916165","rankId":"2","rankName":"下午","startTime":"14:30","endTime":"15:00","fee":"0","feeCode":"","regCount":"4","noVisits":"1","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916166","rankId":"2","rankName":"下午","startTime":"15:00","endTime":"15:30","fee":"0","feeCode":"","regCount":"3","noVisits":"1","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916167","rankId":"2","rankName":"下午","startTime":"15:30","endTime":"16:00","fee":"0","feeCode":"","regCount":"4","noVisits":"1","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916168","rankId":"2","rankName":"下午","startTime":"16:00","endTime":"16:30","fee":"0","feeCode":"","regCount":"4","noVisits":"1","visitDate":"'. $date.'","timeSlot":null},{"doctId":"10446","regId":"916169","rankId":"2","rankName":"下午","startTime":"16:30","endTime":"17:00","fee":"0.01","feeCode":"","regCount":"5","noVisits":"1","visitDate":"'. $date.'","timeSlot":null}]}]}';

        return $this;
    }

    private function mockConfirmRegister(array $params): self
    {
        $date = &$params['json']['date'];
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":{"visitNo":"5358197","waitNum":"","treaID":"1-4","date":"2025-01-22","startTime":"16:30","endTime":"17:00","oppatNo":"288712335574","depLocation":"请到一楼儿童保健门诊","transNo":"","hzrs":"1"}}';

        return $this;
    }

    /**
     * mockGetRegisterRecordLists
     * @param array $params
     * @return self
     */
    private function mockGetRegisterRecordLists(array $params): self
    {
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":[{"visitNo":"5348615","registrationType":"当天挂号","status":"0","waitNum":null,"treaId":"1-3","registrationDate":"2025-01-17","patientId":"2235574","patientName":"谭玉山","rankId":"2","rankName":"下午","startTime":"16:30","endTime":"17:00","oppatNo":"288712335574","depLocation":"请到一楼儿童保健门诊","transNum":null,"orderType":"","payFee":"0","payId":null,"depId":"12","depName":"儿保门诊","doctorId":"10977","doctorName":"杜丽丽","regSource":"自助机","timeSpam":"下午:16:30-17:00","serialNumber":null}]}';

        return $this;
    }

    /**
     * mockCheckRefundRegisterStatus
     * @param array $params
     * @return self
     */
    private function mockCheckRefundRegisterStatus(array $params): self
    {
        $this->transfer_response = '{"status":200,"success":false,"msg":"退号取消检查不通过:当前挂号已过了挂号效期,不能重复退号","msgDev":null,"response":null}';

        return $this;
    }

    /**
     * mockRefundRegister
     * @param array $params
     * @return self
     */
    private function mockRefundRegister(array $params): self
    {
        $this->transfer_response = '{"status":200,"success":true,"msg":"退号成功","msgDev":null,"response":null}';

        return $this;
    }

    /**
     * mockGetPendingLists
     * @param array $params
     * @return $this
     */
    private function mockGetPendingLists(array $params)
    {
        $date_1 = date('Ymd');
        $date_2 = date('Y-m-d');
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":[{"idCardNo":"230403199903245493","visitType":"门诊","visitDate":"'.$date_1.'","strVisitDate":"'.$date_2.'","outpatientDiagnosis":"健康查体,健康查体,健康查体,健康查体,健康查体,健康查体,健康查体","treatmentDepartment":"132","departmentName":"急诊内科","regId":"0","prescriptionId":"1-17488657","prescriptionAmount":"1","singleAmount":"1","doctorId":"10365","doctorName":"管理员","remarks":"","isexpense":"1","strExpense":"自费","nrescriptionNumber":"1-17488657","takeMedicine":null,"visitNumber":"3896308"}]}';

        return $this;
    }

    /**
     * mockGetPendingDetails
     * @param array $params
     * @return $this
     */
    private function mockGetPendingDetails(array $params)
    {
        $date = date('Y-m-d');
        $this->transfer_response = '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":[{"feeDate":"'.$date.'","itemNo":"11283271","projectNumber":"1547","entryName":"0.9%氯化钠注射液G","unitPrice":"1","quantity":"1","money":"1","remarks":null,"projectSpecifications":"100ML:0.9G/瓶","prescriptionNumber":"1-17488657","company":"瓶","prescriptionType":"西药","treatmentDepartment":"132","departmentName":"急诊内科","doctorNumber":"10365","doctorName":"管理员","ysybdm":"D440402003702","gjmlbm":"XB05XAL211B002030902763"}]}';

        return $this;
    }

    /**
     * mockConfirmPayment
     * @param array $params
     * @return $this
     */
    private function mockConfirmPayment(array $params)
    {
        $this->transfer_response = '{"status":200,"success":true,"msg":"自助缴费确认成功","msgDev":null,"response":{"remarks":"","treaId":"6497702","hosTranNo":"ZZ00000049","phyAddress":"门诊西药房","listRecipeRecResults":[{"itemNo":"1547","projectNumber":"1547","entryName":"0.9%氯化钠注射液G","unitPrice":"1","quantity":"1","money":"1","remarks":"","projectSpecifications":"100ML:0.9G/瓶","prescriptionNumber":"1-17488657"}]}}';

        return $this;
    }

    /**
     * mockGetPaidLists
     * @param array $params
     * @return self
     */
    private function mockGetPaidLists(array $params): self
    {
        $this->transfer_response = '{"RESULTCODE":"0","ERRORMSG":"","RECORD":[{"PATIENTID":"D00589351","NAME":"叶子璐","SEX":"女","CHARGETYPE":"自费","VISITDATE":"2012-08-21","RCPTID":"1111","RCPTNO":"90001","COSTS":["250.59","250.59"],"GRZF":"250.59","JJZF":"0","ISPRINTED":"0"},{"PATIENTID":"D00589351","NAME":"叶子璐","SEX":"女","CHARGETYPE":"自费","VISITDATE":"2012-08-21","RCPTID":"1111","RCPTNO":"90002","COSTS":["260.59","260.59"],"GRZF":"260.59","JJZF":"0","ISPRINTED":"0"}]}';

        return $this;
    }

    /**
     * mockGetPaidDetails
     * @param array $params
     * @return self
     */
    private function mockGetPaidDetails(array $params): self
    {
        $this->transfer_response = '{"RESULTCODE":"0","ERRORMSG":"","JSRQ":"2021-07-1715:22:31","TREAID":"3324497","HOSTRANNO":"0000986299","COSTS":"65.9","GRZF":"65.9","JJZF":"","PHYADDRESS":"智能药房","DEPNAME":"急诊科","DOCTNAME":"梁锦胜","CYZD":"1.慢性喘息性支气管炎急性发作","CZGH":"818","RECORD":{"ITEMREC":[{"VISITDATE":"2021-07-1715:13:32","CLASSNAME":"西药费","ITEMNAME":"0.9%氯化钠注射液","ITEMSPEC":"100ML","UNITS":"瓶","AMOUNT":"1","PRICE":"2.42","COSTS":"2.42","ZTMC":"","YCJL":"100","JLDW":"ML","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B002","YJBM":"86902763001266","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:14:45","CLASSNAME":"西药费","ITEMNAME":"复方甘草酸苷片","ITEMSPEC":"20mg","UNITS":"瓶","AMOUNT":"1","PRICE":"15.50","COSTS":"15.50","ZTMC":"","YCJL":"100","JLDW":"片","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B003","YJBM":"86902763001267","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:15:02","CLASSNAME":"西药费","ITEMNAME":"头孢克肟胶囊","ITEMSPEC":"250mg","UNITS":"盒","AMOUNT":"1","PRICE":"18.30","COSTS":"18.30","ZTMC":"","YCJL":"100","JLDW":"粒","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B004","YJBM":"86902763001268","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:16:10","CLASSNAME":"西药费","ITEMNAME":"氯氮平片","ITEMSPEC":"25mg","UNITS":"瓶","AMOUNT":"1","PRICE":"22.00","COSTS":"22.00","ZTMC":"","YCJL":"100","JLDW":"片","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B005","YJBM":"86902763001269","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:17:25","CLASSNAME":"西药费","ITEMNAME":"安定片","ITEMSPEC":"5mg","UNITS":"瓶","AMOUNT":"1","PRICE":"13.40","COSTS":"13.40","ZTMC":"","YCJL":"100","JLDW":"片","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B006","YJBM":"86902763001270","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:18:42","CLASSNAME":"西药费","ITEMNAME":"阿莫西林胶囊","ITEMSPEC":"500mg","UNITS":"瓶","AMOUNT":"1","PRICE":"8.00","COSTS":"8.00","ZTMC":"","YCJL":"100","JLDW":"粒","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B007","YJBM":"86902763001271","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:19:10","CLASSNAME":"西药费","ITEMNAME":"双氯芬酸钠胶囊","ITEMSPEC":"50mg","UNITS":"瓶","AMOUNT":"1","PRICE":"16.80","COSTS":"16.80","ZTMC":"","YCJL":"100","JLDW":"粒","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B008","YJBM":"86902763001272","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:19:45","CLASSNAME":"西药费","ITEMNAME":"利血平片","ITEMSPEC":"25mg","UNITS":"瓶","AMOUNT":"1","PRICE":"12.30","COSTS":"12.30","ZTMC":"","YCJL":"100","JLDW":"片","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B009","YJBM":"86902763001273","YBFL":"甲类","YGXM":"梁锦胜"},{"VISITDATE":"2021-07-1715:20:10","CLASSNAME":"西药费","ITEMNAME":"依普利酮片","ITEMSPEC":"25mg","UNITS":"瓶","AMOUNT":"1","PRICE":"30.00","COSTS":"30.00","ZTMC":"","YCJL":"100","JLDW":"片","YYTS":"1","MRCS":"1","PCMC":"QD","YPBM":"X-B05XA-L211-B010","YJBM":"86902763001274","YBFL":"甲类","YGXM":"梁锦胜"}]}}';

        return $this;
    }

    private function mockCreateElectronInvoice(array $params)
    {
        return [
            'status' => 'success',
            'message' => 'Electron invoice created successfully.',
            'data' => $params
        ];
    }

    private function mockSendElectronInvoiceToHis(array $params)
    {
        return [
            'status' => 'success',
            'message' => 'Electron invoice sent successfully.',
            'data' => $params
        ];
    }

    /**
     * mockGetDictionaryLists
     * @param array $params
     * @return self
     */
    private function mockGetDictionaryLists(array $params): self
    {
        $this->transfer_response =  '{"status":200,"success":true,"msg":"成功","msgDev":null,"response":[{"typeId":"4","typeName":"草药费"},{"typeId":"20","typeName":"防疫药品"},{"typeId":"2","typeName":"西药费"},{"typeId":"3","typeName":"中成药"},{"typeId":"22","typeName":"B超"},{"typeId":"25","typeName":"CT检查"},{"typeId":"19","typeName":"X光费"},{"typeId":"1","typeName":"床位费"},{"typeId":"27","typeName":"高值耗材"},{"typeId":"12","typeName":"挂号费"},{"typeId":"11","typeName":"护理费"},{"typeId":"17","typeName":"急诊留观床位费"},{"typeId":"5","typeName":"检查费"},{"typeId":"9","typeName":"检验费"},{"typeId":"15","typeName":"救护车"},{"typeId":"26","typeName":"内镜检查"},{"typeId":"10","typeName":"其它"},{"typeId":"8","typeName":"手术费"},{"typeId":"13","typeName":"输血费"},{"typeId":"14","typeName":"输氧费"},{"typeId":"23","typeName":"碎石"},{"typeId":"21","typeName":"心电图"},{"typeId":"24","typeName":"一般诊疗费"},{"typeId":"16","typeName":"医材费"},{"typeId":"7","typeName":"诊查费"},{"typeId":"6","typeName":"治疗费"},{"typeId":"18","typeName":"自负床位费"}]}';

        return $this;
    }

    /**
     * mockGetChargeList
     * @param array $params
     * @return self
     */
    private function mockGetChargeList(array $params): self
    {
        $this->transfer_response =  '<RESPONSE><RESULTCODE>0</RESULTCODE><ERRORMSG></ERRORMSG><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>苯巴比妥片</COSTNAME><UNIT>片</UNIT><COSTSPEC>30MG</COSTSPEC><CDNAME>上海信谊药厂</CDNAME><PRICE>0.097</PRICE><REMARK></REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>阿莫西林胶囊</COSTNAME><UNIT>粒</UNIT><COSTSPEC>500MG</COSTSPEC><CDNAME>华北制药厂</CDNAME><PRICE>0.12</PRICE><REMARK>用于治疗细菌感染</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>复方氯噻吨片</COSTNAME><UNIT>片</UNIT><COSTSPEC>0.25G</COSTSPEC><CDNAME>长春药业</CDNAME><PRICE>0.15</PRICE><REMARK>缓解高血压症状</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>洛伐他汀片</COSTNAME><UNIT>片</UNIT><COSTSPEC>20MG</COSTSPEC><CDNAME>中科院制药</CDNAME><PRICE>0.25</PRICE><REMARK>降低血脂</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>维生素C片</COSTNAME><UNIT>片</UNIT><COSTSPEC>500MG</COSTSPEC><CDNAME>美国善格</CDNAME><PRICE>0.05</PRICE><REMARK>增强免疫力</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>布洛芬片</COSTNAME><UNIT>片</UNIT><COSTSPEC>200MG</COSTSPEC><CDNAME>华药集团</CDNAME><PRICE>0.1</PRICE><REMARK>缓解轻度疼痛</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>氯氮平片</COSTNAME><UNIT>片</UNIT><COSTSPEC>25MG</COSTSPEC><CDNAME>南京医药</CDNAME><PRICE>0.3</PRICE><REMARK>用于治疗精神分裂症</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>头孢克肟胶囊</COSTNAME><UNIT>粒</UNIT><COSTSPEC>500MG</COSTSPEC><CDNAME>石药集团</CDNAME><PRICE>0.18</PRICE><REMARK>抗菌药物</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>硝苯地平片</COSTNAME><UNIT>片</UNIT><COSTSPEC>10MG</COSTSPEC><CDNAME>国药集团</CDNAME><PRICE>0.2</PRICE><REMARK>用于治疗高血压</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>美托洛尔片</COSTNAME><UNIT>片</UNIT><COSTSPEC>25MG</COSTSPEC><CDNAME>拜耳制药</CDNAME><PRICE>0.22</PRICE><REMARK>用于治疗心脏病</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>甲硝唑片</COSTNAME><UNIT>片</UNIT><COSTSPEC>250MG</COSTSPEC><CDNAME>南京同仁堂</CDNAME><PRICE>0.12</PRICE><REMARK>用于治疗感染</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>阿托伐他汀片</COSTNAME><UNIT>片</UNIT><COSTSPEC>10MG</COSTSPEC><CDNAME>默沙东</CDNAME><PRICE>0.3</PRICE><REMARK>调节血脂</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>硫酸氢氯噻吨片</COSTNAME><UNIT>片</UNIT><COSTSPEC>12.5MG</COSTSPEC><CDNAME>齐鲁制药</CDNAME><PRICE>0.15</PRICE><REMARK>用于治疗水肿</REMARK></ITEM><ITEM><TYPENAME>西药费</TYPENAME><COSTNAME>兰索拉唑胶囊</COSTNAME><UNIT>粒</UNIT><COSTSPEC>30MG</COSTSPEC><CDNAME>百时美施贵宝</CDNAME><PRICE>0.18</PRICE><REMARK>治疗胃酸过多</REMARK></ITEM></RESPONSE>';

        return $this;
    }
}
